@@ -299,9 +299,11 @@ struct ffsox_analyze_config {
   ffsox_block_config_t shortterm;
   FILE *f;
   int dump;
+  int ai;
+  int vi;
 };
 
-int ffsox_analyze(ffsox_analyze_config_t *ac);
+int ffsox_analyze(ffsox_analyze_config_t *ac, int ai, int vi);
 
 /// node //////////////////////////////////////////////////////////////////////
 #define FFSOX_STATE_RUN      0
